use warnings;
use strict;
use Debian::Debhelper::Dh_Lib;

insert_before ("dh_auto_configure", "dh_octave_version");
if (not get_buildoption ("nocheck")) {
    insert_after ("dh_auto_install", "dh_octave_check");
}
insert_after ("dh_install", "dh_octave_substvar");
insert_after ("dh_installchangelogs", "dh_octave_changelogs");

1;
