package Debian::Debhelper::Buildsystem::octave;

use strict;
use warnings;
use parent qw(Debian::Debhelper::Buildsystem);

sub DESCRIPTION {
    "Octave"
}

sub install {
    my $this = shift;
    $this->doit_in_sourcedir ("octave",
                              "--no-gui",
                              "--no-history",
                              "--silent",
                              "--no-init-file",
                              "--no-window-system",
                              "/usr/share/dh-octave/install-pkg.m")
}

sub clean {
    my $this = shift;
    $this->doit_in_sourcedir_noerror ("dh_octave_clean");
}

1;
